yt.fields.interpolated\_fields module
=====================================

.. automodule:: yt.fields.interpolated_fields
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
